/**
 * 剧情
 */

import { HARITYPE, NOWCLUE } from "../config/enum";
import { ERRORENUM } from "../config/errorEnum";
import { systemConfig } from "../config/serverConfig";
import { guyongTableData, juqingTableData, NPCTableData } from "../data/table/tableData";
import { successResult } from "../tools/systemTools";
import { BizError } from "../util/bizError";
import { changeJsonData, getJsonData } from "../util/tools";
import { addClue, xfxxClue } from "./clue";


/**
 * 剧情
 * @param type 游戏板块
 * @param playId 剧情id
 * @param dhId 对话id(后置剧情id)
 * @returns 
 */
export function getPlayData(userId:string, type:string, playId:string, dhId:string) {
    let excelData = juqingTableData(type, playId);

    /**获取玩家昵称 */
    let userData = getJsonData("json/用户.json");
    let name = "";
    userData.forEach( info => {
        if (info.userId == userId) {
            if (info["name"]) name = info["name"]
            else name = info.loginId;
        }
    })

    let playData = excelData[playId].dataList;
    let nextStory:any = {};
    playData.forEach( info => {
        let {dhid, dh, jqlx, hzjqid, glnpc, glxsid} = info;

        if (dhid == dhId) {
            //根据传入的id查找对应对话
            nextStory = info;
            nextStory["img"] = `${systemConfig.ipUrl}NPC/${glnpc}.png`;
            if(nextStory.dhlx == "玩家") nextStory.glnpc = name;

            //记录当前走到的剧情
            plotClues(userId, type, playId, dhId, glxsid);

            
            /**根据走过的剧情添加线索 */






            

        }
    });

    if (nextStory) {
        let dhStory = [];
        if(nextStory.jqlx == "选择") {
            nextStory.hzjqid = JSON.parse(nextStory.hzjqid);
            for (let i = 0; i < nextStory.hzjqid.length; i++ ) {
                let dhData = playData.find(s => s.dhid == nextStory.hzjqid[i]);
                if(dhData) dhStory.push(dhData);
            }
            nextStory.hzjq = dhStory;
            nextStory.img = `${systemConfig.ipUrl}NPC/${nextStory.glnpc}.png`
            if(nextStory.dhlx == "玩家") nextStory.glnpc = name;
        }

        if (nextStory.hzjqid == '999') {
            //剧情走完添加对应用户的对应线索数据
            addClue(userId);
            xfxxClue();
            /**剧情完成可添加SWOT线索 */
            let allClueJson = getJsonData("json/基础数据.json");
            allClueJson[userId]["SWOT"] = true;
            //更新json数据
            changeJsonData("json/基础数据.json", allClueJson);
        }
    }



    













    return nextStory;
}


/**
 * 酒馆剧情
 * @param type 酒馆
 * @param playId SO12
 * @param dhId 对话id(后置剧情id)
 * @returns 
 */
export function getJGPlayData(userId:string, type:string, playId:string, dhId:string) {
    let allClueJson = getJsonData("json/基础数据.json");

    /**获取玩家昵称 */
    let userData = getJsonData("json/用户.json");
    let name = "";
    userData.forEach( info => {
        if (info.userId == userId) {
            if (info["name"]) name = info["name"]
            else name = info.loginId;
        }
    })

    let duihua = `${playId}_1`;
    if (allClueJson[userId]["酒馆剧情"] > HARITYPE.未开始) {
        duihua = `${playId}_${allClueJson[userId]["酒馆剧情"]}`;
    }
    
    /**剧情完成可添加ROI线索 */
    let excelData = juqingTableData(type, duihua);
    let playData = excelData[duihua].dataList;

    let nextStory:any = {};
    playData.forEach( info => {
        let {dhid, dh, jqlx, hzjqid, glnpc, glxsid} = info;

        if (dhid == dhId) {
            //根据传入的id查找对应对话
            nextStory = info;
            nextStory["img"] = `${systemConfig.ipUrl}NPC/${glnpc}.png`;
            if(nextStory.dhlx == "玩家") nextStory.glnpc = name;

            //记录当前走到的剧情
            plotClues(userId, type, duihua, dhId, glxsid);
        }
    });

    if (nextStory) {
        let dhStory = [];
        if(nextStory.jqlx == "选择") {
            nextStory.hzjqid = JSON.parse(nextStory.hzjqid);
            for (let i = 0; i < nextStory.hzjqid.length; i++ ) {
                let dhData = playData.find(s => s.dhid == nextStory.hzjqid[i]);
                dhData["ispop"] = false;
                if(dhData.jqlx == "工人" || dhData.jqlx == "画师" || dhData.jqlx == "掌柜") {
                    dhData.ispop = true;
                }
                if(dhData) dhStory.push(dhData);
            }
            nextStory.hzjq = dhStory;
            nextStory.img = `${systemConfig.ipUrl}NPC/${nextStory.glnpc}.png`;
            if(nextStory.dhlx == "玩家") nextStory.glnpc = name;
            
        }
        
    }

    if (nextStory.hzjqid == '999') {
        //剧情走完添加对应用户的全部线索
        addClue(userId);
        xfxxClue();
        allClueJson[userId]["酒馆剧情"] = HARITYPE.已选择;
        //酒馆剧情观看完毕、颜料瓷器已选择、SWOT已确认、工人已选择
        if(allClueJson[userId]["酒馆剧情"] == HARITYPE.已选择 && allClueJson[userId]["商行选择"]) allClueJson[userId]["ROI"] = true;
        //更新json数据
        changeJsonData("json/基础数据.json", allClueJson);
    }

    return nextStory;
}


/**
 * 获取对应游戏板块的NPC
 * @param type 
 * @returns 
 */
export function getNPCData(type) {
    let excelData = NPCTableData();
    let npcData = excelData['NPC'].dataList;

    let npcByType = [];
    npcData.forEach( info => {
        let {mc, lx, npc, dyjqid} = info;
        if(lx == type) {
            npcByType.push({name:mc, type:lx, img:`${systemConfig.ipUrl}NPC/${mc}.png`, npc, jqid:dyjqid})
        }
    })

    return npcByType;
}


/**
 * 剧情相关线索
 */
export function plotClues(userId:string, type:string, playId:string, dhId:string, glxsid:string) {
    //获取已有json数据
    let baseData = getJsonData("json/基础数据.json");

    let userData = {};
    if(Object.keys(baseData).length === 0) { //没有对应数据的情况
        userData = {
            "初始资金": 500,
            "天数":1,
            "结算":500,
            "广州府介绍": true, //广州府第一次介绍：true
            "酒馆剧情": HARITYPE.未开始, //酒馆已选择雇佣工人：true
            "当前线索确认": NOWCLUE.未开始,
            "商行选择":false,
            "SWOT": false,
            "ROI": false,
            "竞合": false
        }
        userData[type] = {};
        if (Object.keys(userData[type]).length === 0) {
            userData[type][playId] = {"当前对话id": dhId, "已获得的线索":[]};
            
            if (glxsid) {
                let fruitsEmpty;
                if(glxsid.includes('，')) fruitsEmpty = glxsid.split("，");
                else fruitsEmpty = [glxsid];

                if(!userData[type][playId]["已获得的线索"]) userData[type][playId]["已获得的线索"] = fruitsEmpty
                else {
                    for(let i = 0; i < fruitsEmpty.length; i++) {
                        userData[type][playId]["已获得的线索"].push(fruitsEmpty[i]);
                        let uniqueArray = [...new Set(userData[type][playId]["已获得的线索"])];
                        userData[type][playId]["已获得的线索"] = uniqueArray;
                    }
                }
            }
        }
    } else { //已经有对应数据
        userData = baseData[userId];
        // userData["结算"] = baseData["1727399696222"]["结算"] + 50; //暂时一个剧情对话回合加50银两
        if (!userData[type]) {
            userData[type] = {};
            if(!userData[type][playId]) userData[type][playId] = {"当前对话id":"", "已获得的线索":[]};
            userData[type][playId]["当前对话id"] = dhId;
            userData[type][playId]["已获得的线索"] = [];
            
            if (glxsid) {
                let fruitsEmpty;
                if(glxsid.includes('，')) fruitsEmpty = glxsid.split("，");
                else fruitsEmpty = [glxsid];

                if(!userData[type][playId]["已获得的线索"]) userData[type][playId]["已获得的线索"] = fruitsEmpty
                else {
                    for(let i = 0; i < fruitsEmpty.length; i++) {
                        userData[type][playId]["已获得的线索"].push(fruitsEmpty[i]);
                        let uniqueArray = [...new Set(userData[type][playId]["已获得的线索"])];
                        userData[type][playId]["已获得的线索"] = uniqueArray;
                    }
                }
            }
        } else {
            if (userData[type][playId]) {
                if (userData[type][playId]["当前对话id"] == dhId) return;
                else userData[type][playId]["当前对话id"] = dhId;
            } else userData[type][playId] = {"当前对话id":dhId};
            // userData[type][playId]["当前对话id"] = dhId;
            if (glxsid) {
                let fruitsEmpty;
                if(glxsid.includes('，')) fruitsEmpty = glxsid.split("，");
                else fruitsEmpty = [glxsid];

                if(!userData[type][playId]["已获得的线索"]) userData[type][playId]["已获得的线索"] = fruitsEmpty
                else {
                    for(let i = 0; i < fruitsEmpty.length; i++) {
                        /**剧情相关线索 */
                        userData[type][playId]["已获得的线索"].push(fruitsEmpty[i]);
                        let uniqueArray = [...new Set(userData[type][playId]["已获得的线索"])];
                        userData[type][playId]["已获得的线索"] = uniqueArray;
                    }
                }
            }
        }
    }

    let changeData = baseData;
    changeData[userId] = userData
    //更新json数据
    changeJsonData("json/基础数据.json", changeData);

    console.log("基础数据更新成功");
}


/**
 * 雇佣工人信息表格
 * @param playType 剧情类型 
 * @returns 
 */
export function pubHire(playType) {
    let excelData = guyongTableData();
    let hireData = excelData['雇佣表'].dataList;

    let titleList = [];
    if (playType == "工人") titleList = ["工人", "月产量", "费用（两/月）"];
    if (playType == "画师") titleList = ["画师", "月产量", "费用（两/月）"];
    if (playType == "掌柜") titleList = ["掌柜", "月产量", "费用（两/月）"];
    
    let hireWorker = {};
    hireData.forEach( info => {
        let type = info.lx;
        if(!hireWorker[type]) hireWorker[type] = [];
        hireWorker[type].push({xsId:info.xsid, ry:info.ry, sjcl:info.sjcl, gz:info.gz});
    });

    return { titleList, dataList:hireWorker[playType] };
}


/**
 * 提交雇佣工人
 * @param playType 剧情类型
 * @param xsId 线索id 
 */
export function submitHire(userId, playType, xsId) {
    //获取已有json数据
    let hireData = getJsonData("json/雇佣选择.json");
    let hireWorker = hireData;
    let oldxsid = "";
    if (!hireWorker[userId]) hireWorker[userId] = {};
    if (!hireWorker[userId]["人工"]) hireWorker[userId]["人工"] = {};
    else oldxsid = hireWorker[userId]["人工"][playType];
    hireWorker[userId]["人工"][playType] = xsId;

    changeJsonData("json/雇佣选择.json", hireWorker);
    console.log(`雇佣${playType}添加成功，线索id${xsId}`);

    /**雇佣工人成功，扣除工资部分 */
    let excelData = guyongTableData();
    let hireExcel = excelData['雇佣表'].dataList;
    let hireMoney = 0;
    let oldgz = 0;
    hireExcel.forEach( info => {
        if (info.xsid == xsId) hireMoney = parseInt(info.gz);
        if (info.xsid == oldxsid) oldgz = parseInt(info.gz);
    });
    //扣除雇佣工人工资
    let baseData = getJsonData("json/基础数据.json");
    let jisuan = baseData[userId]["结算"] || 0;
    baseData[userId]["结算"] = jisuan + oldgz - hireMoney;
    changeJsonData("json/基础数据.json", baseData);

    return successResult();
}


/**回显雇佣工人 */
export function displayHire(userId) {
    //获取已有json数据
    let hireData = getJsonData("json/雇佣选择.json");
    let hireWorker = {};
    if (!hireData[userId] || Object.keys(hireData[userId]).length === 0) hireData[userId] = {"人工":{"工人": "", "画师": "", "掌柜": ""}};
    hireWorker = hireData[userId]["人工"];

    return hireWorker;
}


/**
 * 颜料、瓷器信息表格
 * @param type 类型 
 * @returns 
 */
export function rawMaterial(type) {
    let excelData = guyongTableData();
    let rawMaterialData = excelData['原材料'].dataList;

    let titleList = [];
    if (type == "颜料") titleList = ["颜料", "费用（两/个）"];
    if (type == "瓷器") titleList = ["瓷器", "费用（两/个）"];
    
    let rawMaterial = {};
    rawMaterialData.forEach( info => {
        let type = info.lx;
        if(!rawMaterial[type]) rawMaterial[type] = [];
        rawMaterial[type].push({xsId:info.xsid, type:info.lx, mc:info.sjmc, jg:info.jg}); //
    });

    return { titleList, dataList:rawMaterial[type] };
}


/**
 * 提交颜料、瓷器
 * @param type 剧情类型
 * @param xsId 线索id 
 */
export function submitRawMaterial(userId, type, xsId) {
    //获取已有json数据
    let rawMaterialData = getJsonData("json/雇佣选择.json");
    let rawMaterial = rawMaterialData;
    let oldxsid = "";
    if (!rawMaterial[userId]) rawMaterial[userId] = {};
    if (!rawMaterial[userId]["原材料"]) rawMaterial[userId]["原材料"] = {};
    else oldxsid = rawMaterial[userId]["原材料"][type];

    rawMaterial[userId]["原材料"][type] = xsId;

    //运输类型默认水路 todo
    rawMaterial[userId]["运输"] = "C037";

    changeJsonData("json/雇佣选择.json", rawMaterial);
    console.log(`选择${type}添加成功，线索id${xsId}`);

    /**购买原材料成功，扣除原材料价格 */
    let excelData = guyongTableData();
    let rawMaterialExcel = excelData['原材料'].dataList;
    let rawMaterialMoney = 0;
    let oldgz = 0;
    rawMaterialExcel.forEach( info => {
        if (info.xsid == xsId) rawMaterialMoney = parseInt(info.jg);
        if (info.xsid == oldxsid) oldgz = parseInt(info.jg);
    });

    //扣除100个瓷器和颜料的价格 todo
    let baseData = getJsonData("json/基础数据.json");
    let jsje = baseData[userId]["结算"] || 0;
    baseData[userId]["结算"] = jsje + oldgz*1000 - rawMaterialMoney*1000;
    
    baseData[userId]["商行选择"] = true;
    //酒馆剧情观看完毕、颜料瓷器已选择、SWOT已确认、工人已选择
    if(baseData[userId]["酒馆剧情"] == HARITYPE.已选择 && baseData[userId]["商行选择"]) baseData[userId]["ROI"] = true;
    changeJsonData("json/基础数据.json", baseData);

    return successResult();
}


/**
 * 回显颜料、瓷器
 * @param userId 
 * @returns 
 */
export function displayRawMaterial(userId) {
    //获取已有json数据
    let hireData = getJsonData("json/雇佣选择.json");
    let hireWorker = {};
    if (!hireData[userId] || Object.keys(hireData[userId]).length === 0) hireData[userId] = {"原材料":{"瓷器":"", "颜料":""}};
    hireWorker = hireData[userId]["原材料"];

    return hireWorker;
}


/**
 * 广州府是否第一次阅读
 * @param userId 
 */
export function getGzf(userId) {
    //获取已有json数据
    let baseJsonData = getJsonData("json/基础数据.json");
    let firstGzf = baseJsonData[userId]["广州府介绍"];
    let writeBaseAll = baseJsonData;
    writeBaseAll[userId]["广州府介绍"] = false;
    
    changeJsonData("json/基础数据.json", writeBaseAll);

    return {firstGzf};
}


/**
 * 广州府介绍
 * @param userId 
 */
export function getIntroduceGzf() {
    //获取已有json数据
    let baseJsonData = getJsonData("json/广州府介绍.json");

    return baseJsonData;
}


/**
 * 是否能进入酒馆剧情
 * @param userId 
 */
export function firstPubHire(userId) {
    let baseJsonData = getJsonData("json/基础数据.json");
    let isEnabled = false;
    /**判断是否确认SWOT线索 */
    if (baseJsonData[userId]["酒馆剧情"] > HARITYPE.未开始) isEnabled = true;
    
    return {isEnabled};
}










