/**
 * 登录
 * 用户.json 登录用户账号信息
 */

import { ERRORENUM } from "../config/errorEnum";
import { successResult } from "../tools/systemTools";
import { BizError } from "../util/bizError";
import { changeJsonData, getJsonData } from "../util/tools";
import { gameLoop, initAllClue } from "./task";



/**
 * 登录
 * @param loginId 账号
 * @param pwd 密码
 */
export function login(loginId, pwd) {
    let userData = getJsonData("json/用户.json");

    let dataInfo = {};
    /**判断是否有对应账号 */
    let hasUser = userData.some(item => item.loginId === loginId);
    if (!hasUser) throw new BizError(ERRORENUM.账号不存在);
    let firstLogin = false;
    userData.forEach( info => {
        initAllClue(info.userId);

        if (info.loginId == loginId) {
            if (info.pwd != pwd) throw new BizError(ERRORENUM.账号或密码错误);
            if (!info.name) firstLogin = true;
            dataInfo = {userId:info.userId, loginId:info.loginId, firstLogin};
            gameLoop(info.userId);
        }

        // dataInfo["firstlogin"] = initAllClue(info.userId);
    })
    
    return dataInfo;
}


/**
 * 注册
 * @param loginId 账号
 * @param pwd 密码
 */
export function register(loginId, pwd) {
    let userData = getJsonData("json/用户.json");

    const NowMs = new Date().valueOf();

    userData.push(
        {
            userId:`${NowMs}`,
            loginId,
            pwd
        }
    );

    changeJsonData("json/用户.json", userData);

    return successResult();
}


/**
 * 基础数据【当前天数、银两数】
 * @returns 
 */
 export function getBaseData(userId) {
    let baseData = getJsonData("json/基础数据.json");
    let basicsData = {
        day:0,
        tael:0
    }
    basicsData.day = baseData[userId]["天数"] || 0;
    basicsData.tael = baseData[userId]["结算"] || 0;

    return basicsData;
}


/**
 * 统计线索数量
 * @param clueType 
 * @returns 
 */
export function getCount(userId) {
    let jsonData = getJsonData("json/全部线索.json");
    let clueData = jsonData[userId];

    let personalData = {
        clue:0,
        tael:0,
        hire:0
    };

    // 线索数
    for (let key in clueData) {
        clueData[key].forEach( info => {
            if (info.isChoice) personalData.clue++
        })
    }
    
    // 银两数
    let baseData = getJsonData("json/基础数据.json");
    personalData.tael = baseData[userId]["结算"];

    // 雇佣人数
    let hireData = getJsonData("json/雇佣选择.json");
    if (hireData[userId]) {
        if (Object.keys(hireData[userId]).length != 0) {
            if (!hireData[userId]["人工"]) hireData[userId]["人工"] = {}
            if (Object.keys(hireData[userId]["人工"]).length != 0) {
                personalData.hire = Object.keys(hireData[userId]["人工"]).length;
            }
        }
    }
    
    return personalData;
}


/**
 * 修改昵称
 * @param userId 
 */
 export function updateName(userId, name) {
    let userData = getJsonData("json/用户.json");
    userData.forEach( info => {
        if (info.userId == userId) {
            info["name"] = name;
        }

    })

    changeJsonData("json/用户.json", userData);

    return successResult();
}









